﻿using System;
using System.Windows.Forms;
using System.Drawing;

namespace ObjectPopulation
{
    public class ObjectData : IComparable<ObjectData>, IEquatable<ObjectData>
    {
        // delegate
        public static Comparison<ObjectData> NameComparison = delegate(ObjectData p, ObjectData q)
        {
            return p.Name.CompareTo(q.Name);
        };

        // property
        public string Name
        {
            get;
            set;
        }

        public string ModelName
        {
            get;
            set;
        }

        public string ModelFile
        {
            get;
            set;
        }

        public Point Position
        {
            get;
            set;
        }

        public int Angle
        {
            get;
            set;
        }

        public int Scale
        {
            get;
            set;
        }

        // constructor
        public ObjectData() : this("", "", "", new Point(0, 0), 0, 1)
        {
        }

        public ObjectData(string name, string modelname,string modelfile, Point position, int angle, int scale)
        {
            this.Name = name;
            this.ModelName = modelname;
            this.ModelFile = modelfile;
            this.Position = position;
            this.Angle = angle;
            this.Scale = scale;
        }

        public ObjectData(ObjectData p)
        {
            this.Name = p.Name;
            this.ModelName = p.ModelName;
            this.ModelFile = p.ModelFile;
            this.Position = p.Position;
            this.Angle = p.Angle;
            this.Scale = p.Scale;
        }

        // method
        public void OutputDebugPrint()
        {
            System.Diagnostics.Trace.WriteLine(
                "이름: " + Name + " 모델: " + ModelName + " 모델파일: " + ModelFile +
                " 위치: " + Position.X + " " + Position.Y + " 회전각: " + Angle + " 크기:" + Scale);
        }

        // needed for sort
        #region IComparable<ObjectData> Members
        public int CompareTo(ObjectData other)
        {
            return Name.CompareTo(other.Name);
        }
        #endregion

        // needed for search
        #region IEquatable<ObjectData> Members
        public bool Equals(ObjectData other)
        {
            return Name.Equals(other.Name) && ModelName.Equals(other.ModelName) && Position.Equals(other.Position) && Angle.Equals(other.Angle) && Scale.Equals(other.Scale);
        }
        #endregion

        // System.Object.ToString method override
        public override string ToString()
        {
            return string.Format("{0},{1},{2},{3},{4},{5},{6}", Name, ModelName, ModelFile, Position.X, Position.Y, Angle, Scale); // csv file format으로 출력
        } 
    }
}
